# neovim-gemini

A Neovim plugin for interacting with the Google AI API (formerly Gemini). Get AI-powered assistance directly within your Neovim editor.

## Requirements

* Neovim 0.8 or higher
* A Google AI API key (obtainable from [https://makersuite.google.com/app/apikey](https://makersuite.google.com/app/apikey))
* `curl` installed on your system

## Installation

Use your favorite Neovim package manager. Here's how to install with Lazy.nvim:

```lua
{
  "your_username/neovim-gemini",
  config = function()
    require("gemini").setup()
  end,
}
```

## Configuration

Set your API key using one of these methods:

1. Environment variable:
```bash
export GEMINI_API_KEY="your-api-key-here"
```

2. Neovim configuration:
```lua
-- In your init.lua
vim.g.gemini_api_key = "your-api-key-here"
```

## Usage

The plugin provides two ways to interact with Gemini:

1. Command Mode:
```vim
:Gemini What is SOLID in software engineering?
```

2. Keymap (default):
- Press `<leader>g` to open an input prompt
- Type your query and press Enter

### Response Window

The AI response appears in a floating window. You can close it using:
- `q` key
- `<Esc>` key
- `<Enter>` key
- `:q` command

## Features

- Floating window interface
- Non-blocking API calls
- Error handling and notifications
- Easy-to-use command and keymap interface
- Support for the latest Gemini 2.0 Flash model

## Troubleshooting

If you encounter issues:

1. Verify your API key is correctly set:
```lua
:lua print(vim.g.gemini_api_key)
```

2. Check if curl is installed:
```bash
curl --version
```

3. Ensure you have billing set up in your Google Cloud project

## License

This project is licensed under the ISC License. See the [LICENSE](LICENSE) file for details.

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.
